==> pymdown-extensions-4.11.tar.gz: pymdown-extensions-4.11/README.md <==
[![Unix Build Status][travis-image]][travis-link]
[![Windows Build Status][appveyor-image]][appveyor-link]
[![Coverage Status][codecov-image]][codecov-link]
[![Requirements Status][requires-image]][requires-link]
[![pypi-version][pypi-image]][pypi-link]
![License][license-image-mit]

# PyMdown Extensions

Extensions for [Python Markdown](https://pythonhosted.org/Markdown/).

# Documentation

Extension documentation is found here: http://facelessuser.github.io/pymdown-extensions/.

# License

License is MIT except for a few exceptions.  See [LICENSE](https://github.com/facelessuser/pymdown-extensions/blob/master/LICENSE.md) for more info.

[codecov-image]: https://img.shields.io/codecov/c/github/facelessuser/pymdown-extensions/master.svg
[codecov-link]: https://codecov.io/github/facelessuser/pymdown-extensions
[travis-image]: https://img.shields.io/travis/facelessuser/pymdown-extensions/master.svg?label=Unix%20Build
[travis-link]: https://travis-ci.org/facelessuser/pymdown-extensions
[appveyor-image]: https://img.shields.io/appveyor/ci/facelessuser/pymdown-extensions/master.svg?label=Windows%20Build
[appveyor-link]: https://ci.appveyor.com/project/facelessuser/pymdown-extensions
[requires-image]: https://img.shields.io/requires/github/facelessuser/pymdown-extensions/master.svg
[requires-link]: https://requires.io/github/facelessuser/pymdown-extensions/requirements/?branch=master
[pypi-image]: https://img.shields.io/pypi/v/pymdown-extensions.svg
[pypi-link]: https://pypi.python.org/pypi/pymdown-extensions
[license-image-mit]: https://img.shields.io/badge/license-MIT-blue.svg

==> pymdown-extensions-6.0.tar.gz: pymdown-extensions-6.0/README.md <==
[![Unix Build Status][travis-image]][travis-link]
[![Windows Build Status][appveyor-image]][appveyor-link]
[![Coverage Status][codecov-image]][codecov-link]
[![Requirements Status][requires-image]][requires-link]
[![pypi-version][pypi-image]][pypi-link]
![License][license-image-mit]

# PyMdown Extensions

Extensions for [Python Markdown](https://python-markdown.github.io).

# Documentation

Extension documentation is found here: http://facelessuser.github.io/pymdown-extensions/.

# License

License is MIT except for a few exceptions.  See [LICENSE](https://github.com/facelessuser/pymdown-extensions/blob/master/LICENSE.md) for more info.

[codecov-image]: https://img.shields.io/codecov/c/github/facelessuser/pymdown-extensions/master.svg
[codecov-link]: https://codecov.io/github/facelessuser/pymdown-extensions
[travis-image]: https://img.shields.io/travis/facelessuser/pymdown-extensions/master.svg?label=Unix%20Build&logo=travis
[travis-link]: https://travis-ci.org/facelessuser/pymdown-extensions
[appveyor-image]: https://img.shields.io/appveyor/ci/facelessuser/pymdown-extensions/master.svg?label=Windows%20Build&logo=appveyor
[appveyor-link]: https://ci.appveyor.com/project/facelessuser/pymdown-extensions
[requires-image]: https://img.shields.io/requires/github/facelessuser/pymdown-extensions/master.svg
[requires-link]: https://requires.io/github/facelessuser/pymdown-extensions/requirements/?branch=master
[pypi-image]: https://img.shields.io/pypi/v/pymdown-extensions.svg?logo=python&logoColor=white
[pypi-link]: https://pypi.python.org/pypi/pymdown-extensions
[license-image-mit]: https://img.shields.io/badge/license-MIT-blue.svg
